use colored::Colorize; // For coloring the output
use std::collections::HashMap;

use crate::Coordinates;

// Output the map based on map vector
pub fn output_map(ground_map: &Vec<Vec<char>>, above_map: &Vec<Vec<char>>, player_coordinates: &Coordinates, distance_you_can_see: &[i16; 2]) 
{
	let blocks: HashMap<char, [u8; 3]> = 
	[
		('X',  [255,0,  0]), // Null
		('\'', [0,  255,0]),  // Grass
		('"', [153,102,0]),  // Dirt
		(';',  [128,128,128]), // Cobbles
		('~',  [0,  0,  255]), // Water/sea
		('D',  [0,  128,128]), // Diamond
		('C',  [0,  0,  0]),  // Coal
		('i',  [138,74 ,24]), // Iron
		('%',  [195,162,103]), // Wood planks
		(':',  [195,162,103]), // Sand
		('[',  [196,196,196]), // Stone
		('^',  [196,128,196]), // Mountain
		('8',  [255,196,196]), // Stone bricks
		('♣',  [0,  153,51]), // Oak tree
	]
	.iter().cloned().collect();

	// Loop over array and print each block
	for i in player_coordinates.z - distance_you_can_see[1]..player_coordinates.z + distance_you_can_see[1] 
	{
		if i >= 0 && i < ground_map.len() as i16 
		{
			for j in player_coordinates.x - distance_you_can_see[0]..player_coordinates.x+distance_you_can_see[0] 
			{
				if j >= 0 && j < ground_map[i as usize].len() as i16 
				{
					let character: char = ground_map[i as usize][j as usize];
					let above_character: char = above_map[i as usize][j as usize];
					// Check if the character is at the current coordinates
					if i == player_coordinates.z && j == player_coordinates.x 
					{
						print!
						(
							"{}",
							" "
							.on_truecolor(40,235,181)
							.truecolor(0,0,0)
						)
					}
					// Else check if there's something on the above y level
					else if blocks.contains_key(&above_character) && above_character != ' ' 
					{
						print!
						(
							"{}",
							above_character // Output's the current block
							.to_string()
							.truecolor(
								blocks.get(&above_character).unwrap()[0],
								blocks.get(&above_character).unwrap()[1],
								blocks.get(&above_character).unwrap()[2]
							)
						)
					}
					// Else print what is below (the ground)
					else if blocks.contains_key(&character) 
					{
						print!
						(
							"{}",
							character // Output's the current block
							.to_string()
							.truecolor(
								blocks.get(&character).unwrap()[0],
								blocks.get(&character).unwrap()[1],
								blocks.get(&character).unwrap()[2]
							)
						)
					}
					// If the character is invalid print a null value
					else 
					{
						print!
						(
							"{}",
							"X"
							.to_string()
							.truecolor(
								blocks.get(&'X').unwrap()[0],
								blocks.get(&'X').unwrap()[1],
								blocks.get(&'X').unwrap()[2]
							)
						)
					}
				}
			}
			println!("");
		}
	}
}
